# orderly-sdk-py

[![PyPI version](https://badge.fury.io/py/orderly-sdk.svg)](https://badge.fury.io/py/orderly-sdk) [![Pdoc Badge](https://img.shields.io/badge/docs-orderly_sdk-green)](https://akagi201.github.io/orderly-sdk-py/)

Orderly.Network Async Python SDK for EVM API(v2)

**Note: Only async Rest and Websocket APIs are maintained.**

## API docs

* <https://orderly.network/docs/build-on-evm/building-on-evm>
